@@ -1,13 +1,13 @@
-__version__ = "1.2.3"
+__version__ = "1.3.1"
 __author__ = "Daniel Schreij"
-
 import os
 import sys
 from QOpenScienceFramework.compat import *
-dirname = safe_decode(os.path.dirname(__file__),
-	enc=sys.getfilesystemencoding())
+dirname = safe_decode(os.path.dirname(__file__), enc=sys.getfilesystemencoding())
 
-import QOpenScienceFramework.widgets
-import QOpenScienceFramework.connection
 import QOpenScienceFramework.manager
+import QOpenScienceFramework.connection
+import QOpenScienceFramework.widgets
+
+
 
